@@ -26,7 +26,7 @@ Pc = 22.064       # MPa
 rhoc = 322.       # kg/m³
 Tc_D2O = 643.847  # K
 Pc_D2O = 21.671   # MPa
-rhoc_D2O = 356    # kg/m³
+rhoc_D2O = 355.9999698294    # kg/m³
 
 Tt = 273.16       # K
 Pt = 611.657e-6   # MPa
@@ -897,6 +897,11 @@ def _Dielectric(rho, T):
     epsilon : float
         Dielectric constant [-]
 
+    Raises
+    ------
+    NotImplementedError : If input isn't in limit
+        * 238 ≤ T ≤ 1200
+
     Examples
     --------
     >>> _Dielectric(999.242866, 298.15)
@@ -910,6 +915,10 @@ def _Dielectric(rho, T):
     Substance for Temperatures from 238 K to 873 K and Pressures up to 1000
     MPa, http://www.iapws.org/relguide/Dielec.html
     """
+    # Check input parameters
+    if T < 238 or T > 1200:
+        raise NotImplementedError("Incoming out of bound")
+
     k = 1.380658e-23
     Na = 6.0221367e23
     alfa = 1.636e-40
