@@ -11,7 +11,6 @@ from math import exp, log, pi
 import warnings
 
 from scipy.constants import Boltzmann as kb
-from scipy.optimize import fsolve
 from .iapws95 import MEoS, IAPWS95
 
 
@@ -191,322 +190,8 @@ class NH3(MEoS):
 
 
 class H2ONH3(object):
-    """
-    Water-Ammonia mixture class with complete functionality
 
-    Parameters
-    ----------
-    T : float
-        Temperature [K]
-    P : float
-        Pressure [MPa]
-    rho : float
-        Density [kg/m³]
-    v : float
-        Specific volume [m³/kg]
-    A : float
-        Mass fraction of dry air in humid air [kg/kg]
-    xa : float
-        Mole fraction of dry air in humid air [-]
-    W : float
-        Mass fraction of water in humid air [kg/kg]
-    xw : float
-        Mole fraction of water in humid air [-]
-
-    Notes
-    -----
-    * It needs two incoming properties of T, P, rho.
-    * v as a alternate input parameter to rho
-    * For composition need one of A, xa, W, xw.
-
-    Returns
-    -------
-    The calculated instance has the following properties:
-        * P: Pressure [MPa]
-        * T: Temperature [K]
-        * g: Specific Gibbs free energy [kJ/kg]
-        * a: Specific Helmholtz free energy [kJ/kg]
-        * v: Specific volume [m³/kg]
-        * rho: Density [kg/m³]
-        * h: Specific enthalpy [kJ/kg]
-        * u: Specific internal energy [kJ/kg]
-        * s: Specific entropy [kJ/kg·K]
-        * cp: Specific isobaric heat capacity [kJ/kg·K]
-        * w: Speed of sound [m/s]
-
-        * alfav: Isobaric cubic expansion coefficient [1/K]
-        * betas: Isoentropic temperature-pressure coefficient [-]
-        * xkappa: Isothermal Expansion Coefficient [-]
-        * ks: Adiabatic Compressibility [1/MPa]
-
-        * A: Mass fraction of dry air in humid air [kg/kg]
-        * xa: Mole fraction of dry air in humid air [-]
-        * W: Mass fraction of water in humid air [kg/kg]
-        * xw: Mole fraction of water in humid air [-]
-        * mu: Relative chemical potential [kJ/kg]
-        * muw: Chemical potential of water [kJ/kg]
-        * M: Molar mass of humid air [g/mol]
-        * HR: Humidity ratio [-]
-        * xa: Mole fraction of dry air [-]
-        * xw: Mole fraction of water [-]
-        * xa_sat: Mole fraction of dry air at saturation state [-]
-        * RH: Relative humidity
-    """
-    kwargs = {"T": 0.0,
-              "P": 0.0,
-              "rho": 0.0,
-              "v": 0.0,
-              "x": None
-              }
-    status = 0
-    msg = "Undefined"
-
-    def __init__(self, **kwargs):
-        """Constructor, define common constant and initinialice kwargs"""
-        self.kwargs = H2ONH3.kwargs.copy()
-        self.__call__(**kwargs)
-
-    def __call__(self, **kwargs):
-        """Make instance callable to can add input parameter one to one"""
-        # Check alernate input parameters
-        if kwargs.get("v", 0):
-            kwargs["rho"] = 1./kwargs["v"]
-            del kwargs["v"]
-
-        self.kwargs.update(kwargs)
-
-        if self.calculable:
-            self.status = 1
-            self.calculo()
-            self.msg = ""
-
-    @property
-    def calculable(self):
-        """Check if inputs are enough to define state"""
-        self._mode = ""
-        if self.kwargs["T"] and self.kwargs["P"]:
-            self._mode = "TP"
-        elif self.kwargs["T"] and self.kwargs["rho"]:
-            self._mode = "Trho"
-        elif self.kwargs["P"] and self.kwargs["rho"]:
-            self._mode = "Prho"
-
-        # Composition definition
-        self._composition = ""
-        if self.kwargs["x"] is not None:
-            self._composition = "x"
-
-        return bool(self._mode) and bool(self._composition)
-
-    def calculo(self):
-        """Calculate procedure"""
-        T = self.kwargs["T"]
-        rho = self.kwargs["rho"]
-        P = self.kwargs["P"]
-
-        # Composition alternate definition
-        if self._composition == "z":
-            z = self.kwargs["z"]
-
-        # Thermodynamic definition
-        if self._mode == "TP":
-            def f(rho):
-                fav = self._fav(T, rho, A)
-                return rho**2*fav["fird"]/1000-P
-            rho = fsolve(f, 1)[0]
-        elif self._mode == "Prho":
-            def f(T):
-                fav = self._fav(T, rho, A)
-                return rho**2*fav["fird"]/1000-P
-            T = fsolve(f, 300)[0]
-
-
-        prop = self._prop(rho, T, z)
-        self.T = T
-        self.rho = rho
-        self.v = 1/rho
-        self.P = prop["P"]
-        self.u = prop["u"]
-        self.s = prop["s"]
-        self.h = prop["h"]
-        self.g = prop["g"]
-        self.a = prop["a"]
-
-        self.cp = prop["cp"]
-        self.cv = prop["cv"]
-        self.w = prop["w"]
-
-        self.fugH2O = prop["fugH2O"]
-        self.fugNH3 = prop["fugNH3"]
-
-    # def derivative(self, z, x, y):
-        # """Wrapper derivative for custom derived properties
-        # where x, y, z can be: P, T, v, rho, u, h, s, g, a"""
-        # return deriv_G(self, z, x, y, self)
-
-    def _eq(self, rho, T, z):
-        def f(parr):
-            rhol, rhov, x, y = parr
-            propl = self._prop(rhol, T, x)
-            propv = self._prop(rhov, T, y)
-
-            return (propl["P"]-propv["P"],
-                    (1-x)*propl["fugH2O"]-(1-y)*propv["fugH2O"],
-                    x*propl["fugNH3"]-y*propv["fugNH3"],)
-
-
-
-
-
-
-        # # TODO: Add equilibrium routine
-        # """Procedure for calculate the composition in saturation state
-
-        # Parameters
-        # ----------
-        # T : float
-            # Temperature [K]
-        # P : float
-            # Pressure [MPa]
-
-        # Returns
-        # -------
-        # Asat : float
-            # Saturation mass fraction of dry air in humid air [kg/kg]
-        # """
-        # if T <= 273.16:
-            # ice = _Ice(T, P)
-            # gw = ice["g"]
-            # rho = ice["rho"]
-        # else:
-            # water = IAPWS95(T=T, P=P)
-            # gw = water.g
-            # rho = water.rho
-
-        # def f(a):
-            # fa = self._fav(T, rho, a)
-            # muw = fa["fir"]+rho*fa["fird"]-a*fa["fira"]
-            # return gw-muw
-        # Asat = fsolve(f, 0.9)[0]
-        # return Asat
-
-    def _Flash(self, T, P, z):
-        """Flash calculation
-        Ref Naji - Conventional and rapid flash claculations"""
-
-        # Generation of trial pahse composition using Wilson correlation
-        k_h2o = IAPWS95.Pc/P*exp(5.373*(1.+IAPWS95.f_acent)*(1.-IAPWS95.Tc/T))
-        k_nh3 = NH3.Pc/P*exp(5.373*(1.+NH3.f_acent)*(1.-NH3.Tc/T))
-
-        def Rachford(beta):
-            return z*(k_nh3-1)/(1-beta*(1-k_nh3)) + \
-                (1-z)*(k_h2o-1)/(1-beta*(1-k_h2o))
-
-        bubble = Rachford(0)
-        dew = Rachford(1)
-        if bubble < 0:
-            # beta < 0, only liquid phase
-            x = z
-            y = z*k_nh3/(bubble+1)
-            beta = 0
-        elif dew >= 0:
-            # beta > 1, only vapor phase
-            x = z/k_nh3/(1-dew)
-            y = z
-            beta = 1
-        else:
-            beta = 0.5
-            while True:
-                betao = beta
-                solucion = fsolve(Rachford, betao, full_output=True)
-                if solucion[2]!=1:
-                    print(solucion)
-                    break
-                else:
-                    beta = solucion[0][0]
-
-                    xi=[]
-                    yi=[]
-                    for zi, ki in zip(self.fraccion, Ki):
-                        xi.append(float(zi/(1-x+x*ki)))
-                        yi.append(float(zi*ki/(1-x+x*ki)))
-
-                    tital=self._fug(self.Z[1], xi)
-                    titav=self._fug(self.Z[0], yi)
-                    fiv=[z*t*self.P for z, t in zip(yi, titav)]
-                    fil=[z*t*self.P for z, t in zip(xi, tital)]
-                    #criterio de convergencia Eq 21
-                    if sum([abs(l/v-1) for l, v in zip(fil, fiv)])< 1e-14 and abs(x-xo) < 1e-10:
-                        break
-                    else:
-                        Ki=[l/v for l, v in zip(tital, titav)]
-
-        if x < 0:
-            x = 0
-        elif x > 1:
-            x = 1
-
-        return x, xi, yi, Ki
-
-
-    def _Bubble_T(self):
-        def f(T):
-            eq=self.__class__(T, self.P.atm, self.mezcla)
-            return sum([k*x for k, x in zip(eq.Ki, self.fraccion)])-1.
-
-        T=fsolve(f, self.T)
-        return unidades.Temperature(T)
-
-    def _Bubble_P(self):
-        def f(P):
-            eq=self.__class__(self.T, P, self.mezcla)
-            return sum([k*x for k, x in zip(eq.Ki, self.fraccion)])-1.
-
-        P=fsolve(f, self.P.atm)
-        return unidades.Pressure(P, "atm")
-
-    def _Dew_T(self):
-        def f(T):
-            eq=self.__class__(T, self.P.atm, self.mezcla)
-            return 1./sum([x/k for k, x in zip(eq.Ki, self.fraccion)])-1.
-
-        T=fsolve(f, self.T)
-        return unidades.Temperature(T)
-
-    def _Dew_P(self):
-        def f(P):
-            eq=self.__class__(self.T, P, self.mezcla)
-            return sum([x/k for k, x in zip(eq.Ki, self.fraccion)])-1.
-
-        P=fsolve(f, self.P.atm)
-        return unidades.Pressure(P, "atm")
-
-
-
-    def _bubbleP(self, T, xl):
-        def f(parr):
-            rhol, rhov, xv = parr
-            propl = self._prop(rhol, T, xl)
-            propv = self._prop(rhov, T, xv)
-            K_h2o = propv["fugH2O"]/propl["fugH2O"]
-            K_nh3 = propv["fugNH3"]/propl["fugNH3"]
-
-            return (propl["P"]-propv["P"],
-                    xl*propl["fugNH3"]-xv*propv["fugNH3"],
-                    K_nh3*xl+K_h2o*(1-xl)-1)
-        rhol, rhov, xv = fsolve(f, (5, 0.01, 1))
-        print(f([rhol, rhov, xv]))
-
-        prop = {}
-        prop["T"] = T
-        liq = self._prop(rhol, T, xl)
-        prop["P"] = liq["P"]
-        prop["rhol"] = rhol
-        prop["rhov"] = rhov
-        prop["xl"] = xl
-        prop["xv"] = xv
-        print(prop)
-        return prop
+    # TODO: Add equilibrium routine
 
     def _prop(self, rho, T, x):
         """Thermodynamic properties of ammonia-water mixtures
