@@ -4,7 +4,7 @@
 """
 Implemented multiparameter equation of state as a Helmholtz free energy
     * IAPWS-95 implementation
-    * Heavy water formulation 2005
+    * Heavy water formulation 2017
 """
 
 
@@ -168,9 +168,16 @@ class MEoS(_fase):
 
     def __call__(self, **kwargs):
         """Make instance callable to can add input parameter one to one"""
-        if kwargs.get("v", 0):
+        # Alternative rho input
+        if "rhom" in kwargs:
+            kwargs["rho"] = kwargs["rhom"]*self.M
+            del kwargs["rhom"]
+        elif kwargs.get("v", 0):
             kwargs["rho"] = 1./kwargs["v"]
             del kwargs["v"]
+        elif kwargs.get("vm", 0):
+            kwargs["rho"] = self.M/kwargs["vm"]
+            del kwargs["vm"]
         self.kwargs.update(kwargs)
 
         if self.calculable:
@@ -950,7 +957,11 @@ class MEoS(_fase):
         fase.alfa = fase.k/1000/fase.rho/fase.cp
         fase.Prandt = fase.mu*fase.cp*1000/fase.k
         if self.name == "water":
-            fase.epsilon = _Dielectric(fase.rho, self.T)
+            try:
+                fase.epsilon = _Dielectric(fase.rho, self.T)
+            except NotImplementedError:
+                fase.epsilon = None
+
             try:
                 fase.n = _Refractive(fase.rho, self.T, self.kwargs["l"])
             except NotImplementedError:
@@ -1137,18 +1148,6 @@ class MEoS(_fase):
             fiot += n*t*((1-exp(-t*tau))**-1-1)
             fiott -= n*t**2*exp(-t*tau)*(1-exp(-t*tau))**-2
 
-        # Especial term for heavy water
-        # if "tau*logtau" in Fi0:
-        #     fio += Fi0["tau*logtau"]*tau*log(tau)
-        #     fiot += Fi0["tau*logtau"]*(log(tau)+1)
-        #     fiot += Fi0["tau*logtau"]/tau
-        # if "tau*logdelta" in Fi0 and delta:
-        #     fio += Fi0["tau*logdelta"]*tau*log(delta)
-        #     fiot += Fi0["tau*logdelta"]*log(delta)
-        #     fiod += Fi0["tau*logdelta"]*tau/delta
-        #     fiodd -= Fi0["tau*logdelta"]*tau/delta**2
-        #     fiodt += Fi0["tau*logdelta"]/delta
-
         # Extension to especial terms of air
         if "ao_exp2" in Fi0:
             for n, g, C in zip(Fi0["ao_exp2"], Fi0["titao2"], Fi0["sum2"]):
@@ -1184,7 +1183,6 @@ class MEoS(_fase):
             firtt: [∂²fir/∂τ²]δ,x  [-]
             firdt: [∂²fir/∂τ∂δ]x  [-]
             firdd: [∂²fir/∂δ²]τ,x  [-]
-            firx: [∂fir/∂x]τ,δ  [-]
 
         References
         ----------
@@ -1236,8 +1234,8 @@ class MEoS(_fase):
             fird += n*delta**d*tau**t*exp(-a*(delta-e)**2-b*(tau-g)**2)*(
                     d/delta-2*a*(delta-e))
             firdd += n*tau**t*exp(-a*(delta-e)**2-b*(tau-g)**2)*(
-                    -2*a*delta**d+4*a**2*delta**d*(delta-e)**2-4*d*a*delta**2*(
-                            delta-e)+d*2*delta)
+                    -2*a*delta**d + 4*a**2*delta**d*(delta-e)**2 -
+                    4*d*a*delta**(d-1)*(delta-e) + d*(d-1)*delta**(d-2))
             firt += n*delta**d*tau**t*exp(-a*(delta-e)**2-b*(tau-g)**2)*(
                     t/tau-2*b*(tau-g))
             firtt += n*delta**d*tau**t*exp(-a*(delta-e)**2-b*(tau-g)**2)*(
@@ -2044,16 +2042,14 @@ class D2O(MEoS):
 
     References
     ----------
-    IAPWS, Revised Release on the IAPS Formulation 1984 for the Thermodynamic
-    Properties of Heavy Water Substance,
-    http://www.iapws.org/relguide/D2O-2005.pdf
+    IAPWS, Release on the IAPWS Formulation 2017 for the Thermodynamic
+    Properties of Heavy Water, http://www.iapws.org/relguide/Heavy-2017.pdf
     IAPWS, Revised Advisory Note No. 3: Thermodynamic Derivatives from IAPWS
     Formulations, http://www.iapws.org/relguide/Advise3.pdf
 
     Notes
     -----
-    The implemented correlation isn't the current IAPWS formulation, it's the
-    preliminary equation to be presented at the 2017 IAPWS meetings.
+    This correlation replace the old 2005 formulation.
     """
     name = "heavy water"
     CASNumber = "7789-20-0"
@@ -2068,84 +2064,41 @@ class D2O(MEoS):
     f_acent = 0.364
     momentoDipolar = 1.9
 
-    # Fi0 = {"ao_log": [0.5399322597e-2, 0],
-    #        "pow": [0, 1, 2, 3, 4, 5],
-    #        "ao_pow": [0.3087155964e2, -.3827264031e2, 0.4424799189,
-    #                   -.1256336874e1, 0.2843343470, -.2401555088e-1],
-    #        "tau*logtau": -.1288399716e2,
-    #        "tau*logdelta": 0.4415884023e1,
-    #        "ao_exp": [], "titao": [],
-    #        "ao_hyp": [], "hyp": []}
-
-    # _constants = {
-    #     "R": 8.3143565, "rhoref": 17.875414*M, "Tref": 643.89,
-
-    #     "nr1": [-0.384820628204e3, 0.108213047259e4, -0.110768260635e4,
-    #             0.164668954246e4, -0.137959852228e4, 0.598964185629e3,
-    #             -0.100451752702e3, 0.419192736351e3, -0.107279987867e4,
-    #             0.653852283544e3, -0.984305985655e3, 0.845444459339e3,
-    #             -0.376799930490e3, 0.644512590492e2, -0.214911115714e3,
-    #             0.531113962967e3, -0.135454224420e3, 0.202814416558e3,
-    #             -0.178293865031e3, 0.818739394970e2, -0.143312594493e2,
-    #             0.651202383207e2, -0.171227351208e3, 0.100859921516e2,
-    #             -0.144684680657e2, 0.128871134847e2, -0.610605957134e1,
-    #             0.109663804408e1, -0.115734899702e2, 0.374970075409e2,
-    #             0.897967147669, -0.527005883203e1, 0.438084681795e-1,
-    #             0.406772082680, -0.965258571044e-2, -0.119044600379e-1],
-    #     "d1": [1, 1, 1, 1, 1, 1, 1, 2, 2, 2, 2, 2, 2, 2, 3, 3, 3, 3, 3, 3, 3,
-    #            4, 4, 4, 4, 4, 4, 4, 5, 5, 6, 6, 7, 7, 8, 8],
-    #     "t1": [0, 1, 2, 3, 4, 5, 6, 0, 1, 2, 3, 4, 5, 6, 0, 1, 2, 3, 4, 5, 6,
-    #            0, 1, 2, 3, 4, 5, 6, 0, 1, 0, 1, 0, 1, 0, 1],
-
-    #     "nr2": [0.382589102341e3, -0.106406466204e4, 0.105544952919e4,
-    #             -0.157579942855e4, 0.132703387531e4, -0.579348879870e3,
-    #             0.974163902526e2, 0.286799294226e3, -0.127543020847e4,
-    #             0.275802674911e4, -0.381284331492e4, 0.293755152012e4,
-    #             -0.117858249946e4, 0.186261198012e3],
-    #     "c2": [1]*14,
-    #     "d2": [1, 1, 1, 1, 1, 1, 1, 2, 2, 2, 2, 2, 2, 2],
-    #     "t2": [0, 1, 2, 3, 4, 5, 6, 0, 1, 2, 3, 4, 5, 6],
-    #     "gamma2": [1.5394]*14}
-
     Fi0 = {"ao_log": [1, 3],
-           "pow": [0, 1, 2, 3, 4, 5],
-           "ao_pow": [-8.6739710041, 6.9611755531],
-           "tau*logtau": -.1288399716e2,
-           "tau*logdelta": 0.4415884023e1,
-           "ao_exp": [0.00863, 0.97454, 2.0646, 0.23528, 0.29555],
-           "titao": [0.4255669437, 2.6093155672, 6.0185106089, 11.3380974051,
-                     29.5101165339],
+           "pow": [0, 1],
+           "ao_pow": [-8.6785029980521, 6.9636373404376],
+           "ao_exp": [0.010633, 0.99787, 2.1483, 0.3549],
+           "titao": [308/Tc, 1695/Tc, 3949/Tc, 10317/Tc],
            "ao_hyp": [], "hyp": []}
 
     _constants = {
-        "R": 8.3144621, "rhoref": 17.77555*M, "Tref": 643.847,
+        "R": 8.3144598,
 
-        "nr1": [0.0105835, 0.99127253, -1.224122, 1.710643, -2.189443,
-                0.1145315],
-        "d1": [4.0, 1.0, 1.0, 2.0, 2.0, 3.0],
-        "t1": [1.0, 0.463, 1.29, 1.307, 1.2165, 0.587],
+        "nr1": [0.0118675032, 2.9662988968, -3.7869557999, 0.9405186104,
+                -0.91798012, -0.0136265695],
+        "d1": [4, 1, 1, 2, 2, 3],
+        "t1": [1, 0.66, 0.9431, 0.542, 0.677, 1.067],
 
-        "nr2": [-0.89875532, -1.597051, -2.804509, 0.33016885,
-                -3.396526, -0.001881],
-        "c2": [1.0, 2.0, 2.0, 1.0, 2.0, 1.0],
-        "d2": [1.0, 1.0, 3.0, 2.0, 2.0, 8.0],
-        "t2": [2.95, 1.713, 1.929, 0.94, 3.033, 0.765],
+        "nr2": [-0.1649561953, -5.5624457002, -4.9497345162, -0.0526711496,
+                -9.3602294045, -0.6355718773],
+        "c2": [1, 2, 2, 1, 2, 2],
+        "d2": [1, 1, 3, 2, 2, 1],
+        "t2": [3.77, 4.55, 5.121, 0.22, 5.434, 2.24],
         "gamma2": [1]*6,
 
-        "nr3": [-0.70355957, -0.20345481, -0.70691398, 2.094255, 3.042546,
-                0.8010728, 0.213384, 0.32335789, -0.0245055, 0.7380677,
-                -0.21484089],
-        "t3": [1.504, 2.85, 1.96, 0.969, 2.576, 2.79, 3.581, 3.67, 1.7, 1.0,
-               4.1],
-        "d3": [1.0, 2.0, 3.0, 1.0, 3.0, 1.0, 1.0, 2.0, 2.0, 2.0, 1.0],
-        "beta3": [0.907, 0.48, 1.223, 2.61, 4.283, 1.4, 0.735, 0.24, 1067.0,
-                  13.27, 1.48],
-        "alfa3": [0.982, 1.34, 1.658, 1.6235, 1.4, 2.206, 0.84, 1.535, 11.33,
-                  3.86, 7.56],
-        "epsilon3": [2.272, 1.375, 0.648, 0.8925, 0.145, 0.291, 2.01, 1.08,
-                     0.96, 0.181, 0.529],
-        "gamma3": [2.263, 2.343, 0.929, 1.0, 1.383, 0.968, 1.695, 2.23, 1.07,
-                   1.297, 2.41]}
+        "nr3": [-0.0397982189, -2.2454381046, 8.6094866025, -2.4724812971,
+                16.3908849971, 2.85881805220, 15.2772603367, -1.8389093973,
+                2.2813734134, 5.2237649193, 0.4219197316, -0.38833488],
+        "t3": [3.36, 1.31, 1.52, 3.38, 3.76, 4.8, 1, 1.676, 3.8, 2.6, 1, 4],
+        "d3": [1, 3, 1, 3, 1, 1, 2, 2, 2, 1, 1, 1],
+        "alfa3": [0.639, 1.4536, 1.5326, 2.4443, 1.3063, 1.362, 3.5532, 1.2923,
+                  2.58, 1.226, 19.18, 19.093],
+        "beta3": [0.4064, 2.4085, 1.29, 8.516, 0.3661, 0.9485, 7.195, 3.34,
+                  6.7977, 0.952, 1176, 1160],
+        "epsilon3": [2.0155, 0.29, 0.5821, 0.2313, 0.6825, 0.961, 1.2565,
+                     0.1533, 0.4198, 0.9661, 0.9402, 0.94],
+        "gamma3": [1.523, 1.3642, 1.74, 1.297, 2.7218, 3.54, 2.466, 0.8115,
+                   1.3637, 2.5616, 1.0491, 1.0486]}
 
     _Pv = {
         "ao": [-0.80236e1, 0.23957e1, -0.42639e2, 0.99569e2, -0.62135e2],
